summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/kernel/tqdnd_x11.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/src/kernel/tqdnd_x11.cpp
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/src/kernel/tqdnd_x11.cpp')
-rw-r--r--tqtinterface/qt4/src/kernel/tqdnd_x11.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/tqtinterface/qt4/src/kernel/tqdnd_x11.cpp b/tqtinterface/qt4/src/kernel/tqdnd_x11.cpp
index 56d00d4..471df70 100644
--- a/tqtinterface/qt4/src/kernel/tqdnd_x11.cpp
+++ b/tqtinterface/qt4/src/kernel/tqdnd_x11.cpp
@@ -81,7 +81,7 @@ extern void qt_leave_modal( TQWidget *widget );
}
#endif
-extern Window qt_x11_tqfindClientWindow( Window, Atom, bool );
+extern Window qt_x11_findClientWindow( Window, Atom, bool );
extern Atom qt_wm_state;
// this stuff is copied from qclb_x11.cpp
@@ -404,7 +404,7 @@ const char* qt_xdnd_atom_to_str( Atom a )
qt_xdnd_drag_types->setAutoDelete( TRUE );
}
TQCString* result;
- if ( !(result=qt_xdnd_drag_types->tqfind( a )) ) {
+ if ( !(result=qt_xdnd_drag_types->find( a )) ) {
const char* mimeType = XGetAtomName( TQPaintDevice::x11AppDisplay(), a );
if ( !mimeType )
return 0; // only happens on protocol error
@@ -425,7 +425,7 @@ Atom* qt_xdnd_str_to_atom( const char *mimeType )
}
Atom * result;
- if ( (result = qt_xdnd_atom_numbers->tqfind( mimeType )) )
+ if ( (result = qt_xdnd_atom_numbers->find( mimeType )) )
return result;
result = new Atom;
@@ -489,7 +489,7 @@ void qt_xdnd_cleanup()
}
-static TQWidget * tqfind_child( TQWidget * tlw, TQPoint & p )
+static TQWidget * find_child( TQWidget * tlw, TQPoint & p )
{
TQWidget * w = tlw;
@@ -608,7 +608,7 @@ void qt_handle_xdnd_position( TQWidget *w, const XEvent * xe, bool passive )
const unsigned long *l = (const unsigned long *)xe->xclient.data.l;
TQPoint p( (l[2] & 0xffff0000) >> 16, l[2] & 0x0000ffff );
- TQWidget * c = tqfind_child( w, p ); // changes p to to c-local coordinates
+ TQWidget * c = find_child( w, p ); // changes p to to c-local coordinates
if (!passive && checkEmbedded(c, xe))
return;
@@ -728,7 +728,7 @@ void qt_handle_xdnd_position( TQWidget *w, const XEvent * xe, bool passive )
// reset
qt_xdnd_target_current_time = CurrentTime;
- TQWidget * source = TQWidget::tqfind( qt_xdnd_dragsource_xid );
+ TQWidget * source = TQWidget::find( qt_xdnd_dragsource_xid );
if ( source && source->isDesktop() && !source->acceptDrops() )
source = 0;
@@ -811,7 +811,7 @@ void qt_xdnd_send_leave()
leave.data.l[3] = 0; // w, h
leave.data.l[4] = 0; // just null
- TQWidget * w = TQWidget::tqfind( qt_xdnd_current_proxy_target );
+ TQWidget * w = TQWidget::find( qt_xdnd_current_proxy_target );
if ( w && w->isDesktop() && !w->acceptDrops() )
w = 0;
@@ -1164,7 +1164,7 @@ void TQDragManager::cancel( bool deleteSource )
}
static
-Window tqfindRealWindow( const TQPoint & pos, Window w, int md )
+Window findRealWindow( const TQPoint & pos, Window w, int md )
{
if ( qt_xdnd_deco && w == qt_xdnd_deco->winId() )
return 0;
@@ -1198,14 +1198,14 @@ Window tqfindRealWindow( const TQPoint & pos, Window w, int md )
if ( XQueryTree( TQPaintDevice::x11AppDisplay(), w, &r, &p, &c, &nc ) ) {
r=0;
for (uint i=nc; !r && i--; ) {
- r = tqfindRealWindow( pos-TQPoint(attr.x,attr.y),
+ r = findRealWindow( pos-TQPoint(attr.x,attr.y),
c[i], md-1 );
}
XFree(c);
if ( r )
return r;
// We didn't tqfind a client window! Just use the
// innermost window.
}
@@ -1282,7 +1282,7 @@ void TQDragManager::move( const TQPoint & globalPos )
if (type)
break;
// tqfind child at the coordinates
if (!XTranslateCoordinates( TQPaintDevice::x11AppDisplay(), src, src,
lx, ly, &lx2, &ly2, &target)) {
target = 0;
@@ -1290,13 +1290,13 @@ void TQDragManager::move( const TQPoint & globalPos )
}
}
if ( qt_xdnd_deco && (!target || target == qt_xdnd_deco->winId()) ) {
- target = tqfindRealWindow(globalPos,rootwin,6);
+ target = findRealWindow(globalPos,rootwin,6);
}
}
TQWidget* w;
if ( target ) {
- w = TQWidget::tqfind( (WId)target );
+ w = TQWidget::find( (WId)target );
if ( w && w->isDesktop() && !w->acceptDrops() )
w = 0;
} else {
@@ -1442,7 +1442,7 @@ void TQDragManager::drop()
drop.data.l[3] = 0;
drop.data.l[4] = 0;
- TQWidget * w = TQWidget::tqfind( qt_xdnd_current_proxy_target );
+ TQWidget * w = TQWidget::find( qt_xdnd_current_proxy_target );
if ( w && w->isDesktop() && !w->acceptDrops() )
w = 0;
@@ -1567,7 +1567,7 @@ static TQByteArray qt_xdnd_obtain_data( const char *format )
TQWidget* w;
if ( qt_xdnd_dragsource_xid && qt_xdnd_source_object &&
- (w=TQWidget::tqfind( qt_xdnd_dragsource_xid ))
+ (w=TQWidget::find( qt_xdnd_dragsource_xid ))
&& (!w->isDesktop() || w->acceptDrops()) )
{
TQDragObject * o = qt_xdnd_source_object;
@@ -1583,8 +1583,8 @@ static TQByteArray qt_xdnd_obtain_data( const char *format )
if ( !qt_xdnd_target_data )
qt_xdnd_target_data = new TQIntDict<TQByteArray>( 17 );
- if ( qt_xdnd_target_data->tqfind( (int)*a ) ) {
- result = *(qt_xdnd_target_data->tqfind( (int)*a ));
+ if ( qt_xdnd_target_data->find( (int)*a ) ) {
+ result = *(qt_xdnd_target_data->find( (int)*a ));
} else {
if ( XGetSelectionOwner( TQPaintDevice::x11AppDisplay(),
qt_xdnd_selection ) == None )
@@ -1198,14 +1198,14 @@ Window tqfindRealWindow( const TQPoint & pos, Window w, int md )
if ( r )
return r;
- // We didn't tqfind a client window! Just use the
+ // We didn't find a client window! Just use the
// innermost window.
}
@@ -1282,7 +1282,7 @@ void TQDragManager::move( const TQPoint & globalPos )
if (type)
break;
- // tqfind child at the coordinates
+ // find child at the coordinates
if (!XTranslateCoordinates( TQPaintDevice::x11AppDisplay(), src, src,
lx, ly, &lx2, &ly2, &target)) {